@@ -27,8 +27,7 @@ import (
 )
 
 func TestGetIssue(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/issues/5", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -53,9 +52,34 @@ func TestGetIssue(t *testing.T) {
 	}
 }
 
+func TestGetIssueByID(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/issues/5", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodGet)
+		fmt.Fprint(w, `{"id":5, "description": "This is test project", "author" : {"id" : 1, "name": "snehal"}, "assignees":[{"id":1}],"merge_requests_count": 1}`)
+	})
+
+	issue, _, err := client.Issues.GetIssueByID(5)
+	if err != nil {
+		log.Fatal(err)
+	}
+
+	want := &Issue{
+		ID:                5,
+		Description:       "This is test project",
+		Author:            &IssueAuthor{ID: 1, Name: "snehal"},
+		Assignees:         []*IssueAssignee{{ID: 1}},
+		MergeRequestCount: 1,
+	}
+
+	if !reflect.DeepEqual(want, issue) {
+		t.Errorf("Issues.GetIssueByID returned %+v, want %+v", issue, want)
+	}
+}
+
 func TestDeleteIssue(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/issues/5", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodDelete)
@@ -69,8 +93,7 @@ func TestDeleteIssue(t *testing.T) {
 }
 
 func TestMoveIssue(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/issues/11/move", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -121,8 +144,7 @@ func TestMoveIssue(t *testing.T) {
 }
 
 func TestListIssues(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/issues", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -151,12 +173,11 @@ func TestListIssues(t *testing.T) {
 	})
 
 	listProjectIssue := &ListIssuesOptions{
-		AuthorID:   Int(01),
-		AssigneeID: AssigneeID(02),
+		AuthorID:   Int(0o1),
+		AssigneeID: AssigneeID(0o2),
 	}
 
 	issues, _, err := client.Issues.ListIssues(listProjectIssue)
-
 	if err != nil {
 		log.Fatal(err)
 	}
@@ -175,8 +196,7 @@ func TestListIssues(t *testing.T) {
 }
 
 func TestListIssuesWithLabelDetails(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/issues", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -219,12 +239,11 @@ func TestListIssuesWithLabelDetails(t *testing.T) {
 	})
 
 	listProjectIssue := &ListIssuesOptions{
-		AuthorID:   Int(01),
-		AssigneeID: AssigneeID(02),
+		AuthorID:   Int(0o1),
+		AssigneeID: AssigneeID(0o2),
 	}
 
 	issues, _, err := client.Issues.ListIssues(listProjectIssue)
-
 	if err != nil {
 		log.Fatal(err)
 	}
@@ -247,8 +266,7 @@ func TestListIssuesWithLabelDetails(t *testing.T) {
 }
 
 func TestListIssuesSearchInTitle(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/issues", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -270,7 +288,6 @@ func TestListIssuesSearchInTitle(t *testing.T) {
 	}
 
 	issues, _, err := client.Issues.ListIssues(listProjectIssue)
-
 	if err != nil {
 		log.Fatal(err)
 	}
@@ -285,9 +302,9 @@ func TestListIssuesSearchInTitle(t *testing.T) {
 		t.Errorf("Issues.ListIssues returned %+v, want %+v", issues, want)
 	}
 }
+
 func TestListIssuesSearchInDescription(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/issues", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -309,7 +326,6 @@ func TestListIssuesSearchInDescription(t *testing.T) {
 	}
 
 	issues, _, err := client.Issues.ListIssues(listProjectIssue)
-
 	if err != nil {
 		log.Fatal(err)
 	}
@@ -326,8 +342,7 @@ func TestListIssuesSearchInDescription(t *testing.T) {
 }
 
 func TestListIssuesSearchByIterationID(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/issues", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -356,7 +371,6 @@ func TestListIssuesSearchByIterationID(t *testing.T) {
 	}
 
 	issues, _, err := client.Issues.ListIssues(listProjectIssue)
-
 	if err != nil {
 		log.Fatal(err)
 	}
@@ -378,11 +392,10 @@ func TestListIssuesSearchByIterationID(t *testing.T) {
 	if !reflect.DeepEqual(want, issues) {
 		t.Errorf("Issues.ListIssues returned %+v, want %+v", issues, want)
 	}
- }
+}
 
 func TestListProjectIssues(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/issues", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -391,8 +404,8 @@ func TestListProjectIssues(t *testing.T) {
 	})
 
 	listProjectIssue := &ListProjectIssuesOptions{
-		AuthorID:   Int(01),
-		AssigneeID: AssigneeID(02),
+		AuthorID:   Int(0o1),
+		AssigneeID: AssigneeID(0o2),
 	}
 	issues, _, err := client.Issues.ListProjectIssues("1", listProjectIssue)
 	if err != nil {
@@ -412,8 +425,7 @@ func TestListProjectIssues(t *testing.T) {
 }
 
 func TestListProjectIssuesSearchByIterationID(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/issues", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -441,8 +453,7 @@ func TestListProjectIssuesSearchByIterationID(t *testing.T) {
 		IterationID: Int(90),
 	}
 
-	issues, _, err := client.Issues.ListProjectIssues(1 ,listProjectIssue)
-
+	issues, _, err := client.Issues.ListProjectIssues(1, listProjectIssue)
 	if err != nil {
 		log.Fatal(err)
 	}
@@ -464,11 +475,10 @@ func TestListProjectIssuesSearchByIterationID(t *testing.T) {
 	if !reflect.DeepEqual(want, issues) {
 		t.Errorf("Issues.ListIssues returned %+v, want %+v", issues, want)
 	}
- }
+}
 
 func TestListGroupIssues(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/groups/1/issues", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -478,8 +488,8 @@ func TestListGroupIssues(t *testing.T) {
 
 	listGroupIssue := &ListGroupIssuesOptions{
 		State:      String("Open"),
-		AuthorID:   Int(01),
-		AssigneeID: AssigneeID(02),
+		AuthorID:   Int(0o1),
+		AssigneeID: AssigneeID(0o2),
 	}
 
 	issues, _, err := client.Issues.ListGroupIssues("1", listGroupIssue)
@@ -500,8 +510,7 @@ func TestListGroupIssues(t *testing.T) {
 }
 
 func TestListGroupIssuesSearchByIterationID(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/groups/1/issues", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -530,7 +539,6 @@ func TestListGroupIssuesSearchByIterationID(t *testing.T) {
 	}
 
 	issues, _, err := client.Issues.ListGroupIssues(1, listProjectIssue)
-
 	if err != nil {
 		log.Fatal(err)
 	}
@@ -552,11 +560,10 @@ func TestListGroupIssuesSearchByIterationID(t *testing.T) {
 	if !reflect.DeepEqual(want, issues) {
 		t.Errorf("Issues.ListIssues returned %+v, want %+v", issues, want)
 	}
- }
+}
 
 func TestCreateIssue(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/issues", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -569,7 +576,6 @@ func TestCreateIssue(t *testing.T) {
 	}
 
 	issue, _, err := client.Issues.CreateIssue("1", createIssueOptions)
-
 	if err != nil {
 		log.Fatal(err)
 	}
@@ -588,8 +594,7 @@ func TestCreateIssue(t *testing.T) {
 }
 
 func TestUpdateIssue(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/issues/5", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPut)
@@ -601,7 +606,6 @@ func TestUpdateIssue(t *testing.T) {
 		Description: String("This is description of an issue"),
 	}
 	issue, _, err := client.Issues.UpdateIssue(1, 5, updateIssueOpt)
-
 	if err != nil {
 		log.Fatal(err)
 	}
@@ -620,8 +624,7 @@ func TestUpdateIssue(t *testing.T) {
 }
 
 func TestSubscribeToIssue(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/issues/5/subscribe", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -629,7 +632,6 @@ func TestSubscribeToIssue(t *testing.T) {
 	})
 
 	issue, _, err := client.Issues.SubscribeToIssue("1", 5)
-
 	if err != nil {
 		log.Fatal(err)
 	}
@@ -648,8 +650,7 @@ func TestSubscribeToIssue(t *testing.T) {
 }
 
 func TestUnsubscribeFromIssue(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/issues/5/unsubscribe", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -675,8 +676,7 @@ func TestUnsubscribeFromIssue(t *testing.T) {
 }
 
 func TestListMergeRequestsClosingIssue(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/issues/5/closed_by", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -702,8 +702,7 @@ func TestListMergeRequestsClosingIssue(t *testing.T) {
 }
 
 func TestListMergeRequestsRelatedToIssue(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/issues/5/related_merge_requests", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -729,8 +728,7 @@ func TestListMergeRequestsRelatedToIssue(t *testing.T) {
 }
 
 func TestSetTimeEstimate(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/issues/5/time_estimate", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -753,8 +751,7 @@ func TestSetTimeEstimate(t *testing.T) {
 }
 
 func TestResetTimeEstimate(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/issues/5/reset_time_estimate", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -773,8 +770,7 @@ func TestResetTimeEstimate(t *testing.T) {
 }
 
 func TestAddSpentTime(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/issues/5/add_spent_time", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -797,8 +793,7 @@ func TestAddSpentTime(t *testing.T) {
 }
 
 func TestResetSpentTime(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/issues/5/reset_spent_time", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -818,8 +813,7 @@ func TestResetSpentTime(t *testing.T) {
 }
 
 func TestGetTimeSpent(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/issues/5/time_stats", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -839,8 +833,7 @@ func TestGetTimeSpent(t *testing.T) {
 }
 
 func TestGetIssueParticipants(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/issues/5/participants", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -855,8 +848,10 @@ func TestGetIssueParticipants(t *testing.T) {
 		log.Fatal(err)
 	}
 
-	want := []*BasicUser{{ID: 1, Name: "User1", Username: "User1", State: "active", AvatarURL: "", WebURL: "https://localhost/User1"},
-		{ID: 2, Name: "User2", Username: "User2", State: "active", AvatarURL: "https://localhost/uploads/-/system/user/avatar/2/avatar.png", WebURL: "https://localhost/User2"}}
+	want := []*BasicUser{
+		{ID: 1, Name: "User1", Username: "User1", State: "active", AvatarURL: "", WebURL: "https://localhost/User1"},
+		{ID: 2, Name: "User2", Username: "User2", State: "active", AvatarURL: "https://localhost/uploads/-/system/user/avatar/2/avatar.png", WebURL: "https://localhost/User2"},
+	}
 
 	if !reflect.DeepEqual(want, issueParticipants) {
 		t.Errorf("Issues.GetIssueParticipants returned %+v, want %+v", issueParticipants, want)
