@@ -27,14 +27,14 @@ import (
 // ServicesService handles communication with the services related methods of
 // the GitLab API.
 //
-// GitLab API docs: https://docs.gitlab.com/ce/api/services.html
+// GitLab API docs: https://docs.gitlab.com/ee/api/services.html
 type ServicesService struct {
 	client *Client
 }
 
 // Service represents a GitLab service.
 //
-// GitLab API docs: https://docs.gitlab.com/ce/api/services.html
+// GitLab API docs: https://docs.gitlab.com/ee/api/services.html
 type Service struct {
 	ID                       int        `json:"id"`
 	Title                    string     `json:"title"`
@@ -59,7 +59,7 @@ type Service struct {
 
 // ListServices gets a list of all active services.
 //
-// GitLab API docs: https://docs.gitlab.com/ce/api/services.html#list-all-active-services
+// GitLab API docs: https://docs.gitlab.com/ee/api/services.html#list-all-active-services
 func (s *ServicesService) ListServices(pid interface{}, options ...RequestOptionFunc) ([]*Service, *Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -78,13 +78,13 @@ func (s *ServicesService) ListServices(pid interface{}, options ...RequestOption
 		return nil, resp, err
 	}
 
-	return svcs, resp, err
+	return svcs, resp, nil
 }
 
 // CustomIssueTrackerService represents Custom Issue Tracker service settings.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#custom-issue-tracker
+// https://docs.gitlab.com/ee/api/services.html#custom-issue-tracker
 type CustomIssueTrackerService struct {
 	Service
 	Properties *CustomIssueTrackerServiceProperties `json:"properties"`
@@ -93,7 +93,7 @@ type CustomIssueTrackerService struct {
 // CustomIssueTrackerServiceProperties represents Custom Issue Tracker specific properties.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#custom-issue-tracker
+// https://docs.gitlab.com/ee/api/services.html#custom-issue-tracker
 type CustomIssueTrackerServiceProperties struct {
 	ProjectURL  string `json:"project_url,omitempty"`
 	IssuesURL   string `json:"issues_url,omitempty"`
@@ -103,7 +103,7 @@ type CustomIssueTrackerServiceProperties struct {
 // GetCustomIssueTrackerService gets Custom Issue Tracker service settings for a project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#get-custom-issue-tracker-service-settings
+// https://docs.gitlab.com/ee/api/services.html#get-custom-issue-tracker-service-settings
 func (s *ServicesService) GetCustomIssueTrackerService(pid interface{}, options ...RequestOptionFunc) (*CustomIssueTrackerService, *Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -122,14 +122,14 @@ func (s *ServicesService) GetCustomIssueTrackerService(pid interface{}, options
 		return nil, resp, err
 	}
 
-	return svc, resp, err
+	return svc, resp, nil
 }
 
 // SetCustomIssueTrackerServiceOptions represents the available SetCustomIssueTrackerService()
 // options.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#createedit-custom-issue-tracker-service
+// https://docs.gitlab.com/ee/api/services.html#createedit-custom-issue-tracker-service
 type SetCustomIssueTrackerServiceOptions struct {
 	NewIssueURL *string `url:"new_issue_url,omitempty" json:"new_issue_url,omitempty"`
 	IssuesURL   *string `url:"issues_url,omitempty" json:"issues_url,omitempty"`
@@ -142,7 +142,7 @@ type SetCustomIssueTrackerServiceOptions struct {
 // SetCustomIssueTrackerService sets Custom Issue Tracker service for a project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#createedit-custom-issue-tracker-service
+// https://docs.gitlab.com/ee/api/services.html#createedit-custom-issue-tracker-service
 func (s *ServicesService) SetCustomIssueTrackerService(pid interface{}, opt *SetCustomIssueTrackerServiceOptions, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -161,7 +161,7 @@ func (s *ServicesService) SetCustomIssueTrackerService(pid interface{}, opt *Set
 // DeleteCustomIssueTrackerService deletes Custom Issue Tracker service settings for a project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#delete-custom-issue-tracker-service
+// https://docs.gitlab.com/ee/api/services.html#delete-custom-issue-tracker-service
 func (s *ServicesService) DeleteCustomIssueTrackerService(pid interface{}, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -180,7 +180,7 @@ func (s *ServicesService) DeleteCustomIssueTrackerService(pid interface{}, optio
 // DroneCIService represents Drone CI service settings.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#drone-ci
+// https://docs.gitlab.com/ee/api/services.html#drone-ci
 type DroneCIService struct {
 	Service
 	Properties *DroneCIServiceProperties `json:"properties"`
@@ -189,7 +189,7 @@ type DroneCIService struct {
 // DroneCIServiceProperties represents Drone CI specific properties.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#drone-ci
+// https://docs.gitlab.com/ee/api/services.html#drone-ci
 type DroneCIServiceProperties struct {
 	Token                 string `json:"token"`
 	DroneURL              string `json:"drone_url"`
@@ -199,7 +199,7 @@ type DroneCIServiceProperties struct {
 // GetDroneCIService gets Drone CI service settings for a project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#get-drone-ci-service-settings
+// https://docs.gitlab.com/ee/api/services.html#get-drone-ci-service-settings
 func (s *ServicesService) GetDroneCIService(pid interface{}, options ...RequestOptionFunc) (*DroneCIService, *Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -218,14 +218,14 @@ func (s *ServicesService) GetDroneCIService(pid interface{}, options ...RequestO
 		return nil, resp, err
 	}
 
-	return svc, resp, err
+	return svc, resp, nil
 }
 
 // SetDroneCIServiceOptions represents the available SetDroneCIService()
 // options.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#createedit-drone-ci-service
+// https://docs.gitlab.com/ee/api/services.html#createedit-drone-ci-service
 type SetDroneCIServiceOptions struct {
 	Token                 *string `url:"token,omitempty" json:"token,omitempty"`
 	DroneURL              *string `url:"drone_url,omitempty" json:"drone_url,omitempty"`
@@ -235,7 +235,7 @@ type SetDroneCIServiceOptions struct {
 // SetDroneCIService sets Drone CI service for a project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#createedit-drone-ci-service
+// https://docs.gitlab.com/ee/api/services.html#createedit-drone-ci-service
 func (s *ServicesService) SetDroneCIService(pid interface{}, opt *SetDroneCIServiceOptions, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -254,7 +254,7 @@ func (s *ServicesService) SetDroneCIService(pid interface{}, opt *SetDroneCIServ
 // DeleteDroneCIService deletes Drone CI service settings for a project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#delete-drone-ci-service
+// https://docs.gitlab.com/ee/api/services.html#delete-drone-ci-service
 func (s *ServicesService) DeleteDroneCIService(pid interface{}, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -270,10 +270,109 @@ func (s *ServicesService) DeleteDroneCIService(pid interface{}, options ...Reque
 	return s.client.Do(req, nil)
 }
 
+// EmailsOnPushService represents Emails on Push service settings.
+//
+// GitLab API docs:
+// https://docs.gitlab.com/ee/api/integrations.html#emails-on-push
+type EmailsOnPushService struct {
+	Service
+	Properties *EmailsOnPushServiceProperties `json:"properties"`
+}
+
+// EmailsOnPushServiceProperties represents Emails on Push specific properties.
+//
+// GitLab API docs:
+// https://docs.gitlab.com/ee/api/integrations.html#emails-on-push
+type EmailsOnPushServiceProperties struct {
+	Recipients             string `json:"recipients"`
+	DisableDiffs           bool   `json:"disable_diffs"`
+	SendFromCommitterEmail bool   `json:"send_from_committer_email"`
+	PushEvents             bool   `json:"push_events"`
+	TagPushEvents          bool   `json:"tag_push_events"`
+	BranchesToBeNotified   string `json:"branches_to_be_notified"`
+}
+
+// GetEmailsOnPushService gets Emails on Push service settings for a project.
+//
+// GitLab API docs:
+// https://docs.gitlab.com/ee/api/integrations.html#get-emails-on-push-integration-settings
+func (s *ServicesService) GetEmailsOnPushService(pid interface{}, options ...RequestOptionFunc) (*EmailsOnPushService, *Response, error) {
+	project, err := parseID(pid)
+	if err != nil {
+		return nil, nil, err
+	}
+	u := fmt.Sprintf("projects/%s/integrations/emails-on-push", PathEscape(project))
+
+	req, err := s.client.NewRequest(http.MethodGet, u, nil, options)
+	if err != nil {
+		return nil, nil, err
+	}
+
+	svc := new(EmailsOnPushService)
+	resp, err := s.client.Do(req, svc)
+	if err != nil {
+		return nil, resp, err
+	}
+
+	return svc, resp, nil
+}
+
+// SetEmailsOnPushServiceOptions represents the available SetEmailsOnPushService()
+// options.
+//
+// GitLab API docs:
+// https://docs.gitlab.com/ee/api/integrations.html#createedit-emails-on-push-integration
+type SetEmailsOnPushServiceOptions struct {
+	Recipients             *string `url:"recipients,omitempty" json:"recipients,omitempty"`
+	DisableDiffs           *bool   `url:"disable_diffs,omitempty" json:"disable_diffs,omitempty"`
+	SendFromCommitterEmail *bool   `url:"send_from_committer_email,omitempty" json:"send_from_committer_email,omitempty"`
+	PushEvents             *bool   `url:"push_events,omitempty" json:"push_events,omitempty"`
+	TagPushEvents          *bool   `url:"tag_push_events,omitempty" json:"tag_push_events,omitempty"`
+	BranchesToBeNotified   *string `url:"branches_to_be_notified,omitempty" json:"branches_to_be_notified,omitempty"`
+}
+
+// SetEmailsOnPushService sets Emails on Push service for a project.
+//
+// GitLab API docs:
+// https://docs.gitlab.com/ee/api/integrations.html#createedit-emails-on-push-integration
+func (s *ServicesService) SetEmailsOnPushService(pid interface{}, opt *SetEmailsOnPushServiceOptions, options ...RequestOptionFunc) (*Response, error) {
+	project, err := parseID(pid)
+	if err != nil {
+		return nil, err
+	}
+	u := fmt.Sprintf("projects/%s/integrations/emails-on-push", PathEscape(project))
+
+	req, err := s.client.NewRequest(http.MethodPut, u, opt, options)
+	if err != nil {
+		return nil, err
+	}
+
+	return s.client.Do(req, nil)
+}
+
+// DeleteEmailsOnPushService deletes Emails on Push service settings for a project.
+//
+// GitLab API docs:
+// https://docs.gitlab.com/ee/api/integrations.html#disable-emails-on-push-integration
+func (s *ServicesService) DeleteEmailsOnPushService(pid interface{}, options ...RequestOptionFunc) (*Response, error) {
+	project, err := parseID(pid)
+	if err != nil {
+		return nil, err
+	}
+	u := fmt.Sprintf("projects/%s/integrations/emails-on-push", PathEscape(project))
+
+	req, err := s.client.NewRequest(http.MethodDelete, u, nil, options)
+	if err != nil {
+		return nil, err
+	}
+
+	return s.client.Do(req, nil)
+}
+
 // ExternalWikiService represents External Wiki service settings.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#external-wiki
+// https://docs.gitlab.com/ee/api/services.html#external-wiki
 type ExternalWikiService struct {
 	Service
 	Properties *ExternalWikiServiceProperties `json:"properties"`
@@ -282,7 +381,7 @@ type ExternalWikiService struct {
 // ExternalWikiServiceProperties represents External Wiki specific properties.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#external-wiki
+// https://docs.gitlab.com/ee/api/services.html#external-wiki
 type ExternalWikiServiceProperties struct {
 	ExternalWikiURL string `json:"external_wiki_url"`
 }
@@ -290,7 +389,7 @@ type ExternalWikiServiceProperties struct {
 // GetExternalWikiService gets External Wiki service settings for a project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#get-external-wiki-service-settings
+// https://docs.gitlab.com/ee/api/services.html#get-external-wiki-service-settings
 func (s *ServicesService) GetExternalWikiService(pid interface{}, options ...RequestOptionFunc) (*ExternalWikiService, *Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -309,14 +408,14 @@ func (s *ServicesService) GetExternalWikiService(pid interface{}, options ...Req
 		return nil, resp, err
 	}
 
-	return svc, resp, err
+	return svc, resp, nil
 }
 
 // SetExternalWikiServiceOptions represents the available SetExternalWikiService()
 // options.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#createedit-external-wiki-service
+// https://docs.gitlab.com/ee/api/services.html#createedit-external-wiki-service
 type SetExternalWikiServiceOptions struct {
 	ExternalWikiURL *string `url:"external_wiki_url,omitempty" json:"external_wiki_url,omitempty"`
 }
@@ -324,7 +423,7 @@ type SetExternalWikiServiceOptions struct {
 // SetExternalWikiService sets External Wiki service for a project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#createedit-external-wiki-service
+// https://docs.gitlab.com/ee/api/services.html#createedit-external-wiki-service
 func (s *ServicesService) SetExternalWikiService(pid interface{}, opt *SetExternalWikiServiceOptions, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -343,7 +442,7 @@ func (s *ServicesService) SetExternalWikiService(pid interface{}, opt *SetExtern
 // DeleteExternalWikiService deletes External Wiki service for project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#delete-external-wiki-service
+// https://docs.gitlab.com/ee/api/services.html#delete-external-wiki-service
 func (s *ServicesService) DeleteExternalWikiService(pid interface{}, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -362,7 +461,7 @@ func (s *ServicesService) DeleteExternalWikiService(pid interface{}, options ...
 // GithubService represents Github service settings.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#github-premium
+// https://docs.gitlab.com/ee/api/services.html#github-premium
 type GithubService struct {
 	Service
 	Properties *GithubServiceProperties `json:"properties"`
@@ -371,7 +470,7 @@ type GithubService struct {
 // GithubServiceProperties represents Github specific properties.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#github-premium
+// https://docs.gitlab.com/ee/api/services.html#github-premium
 type GithubServiceProperties struct {
 	RepositoryURL string `json:"repository_url"`
 	StaticContext bool   `json:"static_context"`
@@ -380,7 +479,7 @@ type GithubServiceProperties struct {
 // GetGithubService gets Github service settings for a project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#get-github-service-settings
+// https://docs.gitlab.com/ee/api/services.html#get-github-service-settings
 func (s *ServicesService) GetGithubService(pid interface{}, options ...RequestOptionFunc) (*GithubService, *Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -399,14 +498,14 @@ func (s *ServicesService) GetGithubService(pid interface{}, options ...RequestOp
 		return nil, resp, err
 	}
 
-	return svc, resp, err
+	return svc, resp, nil
 }
 
 // SetGithubServiceOptions represents the available SetGithubService()
 // options.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#createedit-github-service
+// https://docs.gitlab.com/ee/api/services.html#createedit-github-service
 type SetGithubServiceOptions struct {
 	Token         *string `url:"token,omitempty" json:"token,omitempty"`
 	RepositoryURL *string `url:"repository_url,omitempty" json:"repository_url,omitempty"`
@@ -416,7 +515,7 @@ type SetGithubServiceOptions struct {
 // SetGithubService sets Github service for a project
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#createedit-github-service
+// https://docs.gitlab.com/ee/api/services.html#createedit-github-service
 func (s *ServicesService) SetGithubService(pid interface{}, opt *SetGithubServiceOptions, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -435,7 +534,7 @@ func (s *ServicesService) SetGithubService(pid interface{}, opt *SetGithubServic
 // DeleteGithubService deletes Github service for a project
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#delete-github-service
+// https://docs.gitlab.com/ee/api/services.html#delete-github-service
 func (s *ServicesService) DeleteGithubService(pid interface{}, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -455,7 +554,7 @@ func (s *ServicesService) DeleteGithubService(pid interface{}, options ...Reques
 // options.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#edit-gitlab-ci-service
+// https://docs.gitlab.com/ee/api/services.html#edit-gitlab-ci-service
 type SetGitLabCIServiceOptions struct {
 	Token      *string `url:"token,omitempty" json:"token,omitempty"`
 	ProjectURL *string `url:"project_url,omitempty" json:"project_url,omitempty"`
@@ -464,7 +563,7 @@ type SetGitLabCIServiceOptions struct {
 // SetGitLabCIService sets GitLab CI service for a project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#edit-gitlab-ci-service
+// https://docs.gitlab.com/ee/api/services.html#edit-gitlab-ci-service
 func (s *ServicesService) SetGitLabCIService(pid interface{}, opt *SetGitLabCIServiceOptions, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -483,7 +582,7 @@ func (s *ServicesService) SetGitLabCIService(pid interface{}, opt *SetGitLabCISe
 // DeleteGitLabCIService deletes GitLab CI service settings for a project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#delete-gitlab-ci-service
+// https://docs.gitlab.com/ee/api/services.html#delete-gitlab-ci-service
 func (s *ServicesService) DeleteGitLabCIService(pid interface{}, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -503,7 +602,7 @@ func (s *ServicesService) DeleteGitLabCIService(pid interface{}, options ...Requ
 // options.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#edit-hipchat-service
+// https://docs.gitlab.com/ee/api/services.html#edit-hipchat-service
 type SetHipChatServiceOptions struct {
 	Token *string `url:"token,omitempty" json:"token,omitempty" `
 	Room  *string `url:"room,omitempty" json:"room,omitempty"`
@@ -512,7 +611,7 @@ type SetHipChatServiceOptions struct {
 // SetHipChatService sets HipChat service for a project
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#edit-hipchat-service
+// https://docs.gitlab.com/ee/api/services.html#edit-hipchat-service
 func (s *ServicesService) SetHipChatService(pid interface{}, opt *SetHipChatServiceOptions, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -531,7 +630,7 @@ func (s *ServicesService) SetHipChatService(pid interface{}, opt *SetHipChatServ
 // DeleteHipChatService deletes HipChat service for project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#delete-hipchat-service
+// https://docs.gitlab.com/ee/api/services.html#delete-hipchat-service
 func (s *ServicesService) DeleteHipChatService(pid interface{}, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -588,7 +687,7 @@ func (s *ServicesService) GetJenkinsCIService(pid interface{}, options ...Reques
 		return nil, resp, err
 	}
 
-	return svc, resp, err
+	return svc, resp, nil
 }
 
 // SetJenkinsCIServiceOptions represents the available SetJenkinsCIService()
@@ -628,7 +727,7 @@ func (s *ServicesService) SetJenkinsCIService(pid interface{}, opt *SetJenkinsCI
 // DeleteJenkinsCIService deletes Jenkins CI service for project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#delete-jira-service
+// https://docs.gitlab.com/ee/api/services.html#delete-jira-service
 func (s *ServicesService) DeleteJenkinsCIService(pid interface{}, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -647,7 +746,7 @@ func (s *ServicesService) DeleteJenkinsCIService(pid interface{}, options ...Req
 // JiraService represents Jira service settings.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#jira
+// https://docs.gitlab.com/ee/api/services.html#jira
 type JiraService struct {
 	Service
 	Properties *JiraServiceProperties `json:"properties"`
@@ -656,7 +755,7 @@ type JiraService struct {
 // JiraServiceProperties represents Jira specific properties.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#jira
+// https://docs.gitlab.com/ee/api/services.html#jira
 type JiraServiceProperties struct {
 	URL                   string `json:"url"`
 	APIURL                string `json:"api_url"`
@@ -699,7 +798,7 @@ func (p *JiraServiceProperties) UnmarshalJSON(b []byte) error {
 // GetJiraService gets Jira service settings for a project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#get-jira-service-settings
+// https://docs.gitlab.com/ee/api/services.html#get-jira-service-settings
 func (s *ServicesService) GetJiraService(pid interface{}, options ...RequestOptionFunc) (*JiraService, *Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -718,14 +817,14 @@ func (s *ServicesService) GetJiraService(pid interface{}, options ...RequestOpti
 		return nil, resp, err
 	}
 
-	return svc, resp, err
+	return svc, resp, nil
 }
 
 // SetJiraServiceOptions represents the available SetJiraService()
 // options.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#edit-jira-service
+// https://docs.gitlab.com/ee/api/services.html#edit-jira-service
 type SetJiraServiceOptions struct {
 	URL                   *string `url:"url,omitempty" json:"url,omitempty"`
 	APIURL                *string `url:"api_url,omitempty" json:"api_url,omitempty"`
@@ -742,7 +841,7 @@ type SetJiraServiceOptions struct {
 // SetJiraService sets Jira service for a project
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#edit-jira-service
+// https://docs.gitlab.com/ee/api/services.html#edit-jira-service
 func (s *ServicesService) SetJiraService(pid interface{}, opt *SetJiraServiceOptions, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -761,7 +860,7 @@ func (s *ServicesService) SetJiraService(pid interface{}, opt *SetJiraServiceOpt
 // DeleteJiraService deletes Jira service for project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#delete-jira-service
+// https://docs.gitlab.com/ee/api/services.html#delete-jira-service
 func (s *ServicesService) DeleteJiraService(pid interface{}, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -780,7 +879,7 @@ func (s *ServicesService) DeleteJiraService(pid interface{}, options ...RequestO
 // MattermostService represents Mattermost service settings.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#mattermost-notifications
+// https://docs.gitlab.com/ee/api/services.html#mattermost-notifications
 type MattermostService struct {
 	Service
 	Properties *MattermostServiceProperties `json:"properties"`
@@ -789,7 +888,7 @@ type MattermostService struct {
 // MattermostServiceProperties represents Mattermost specific properties.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#mattermost-notifications
+// https://docs.gitlab.com/ee/api/services.html#mattermost-notifications
 type MattermostServiceProperties struct {
 	WebHook                   string    `json:"webhook"`
 	Username                  string    `json:"username"`
@@ -810,7 +909,7 @@ type MattermostServiceProperties struct {
 // GetMattermostService gets Mattermost service settings for a project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#get-slack-service-settings
+// https://docs.gitlab.com/ee/api/services.html#get-slack-service-settings
 func (s *ServicesService) GetMattermostService(pid interface{}, options ...RequestOptionFunc) (*MattermostService, *Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -829,14 +928,14 @@ func (s *ServicesService) GetMattermostService(pid interface{}, options ...Reque
 		return nil, resp, err
 	}
 
-	return svc, resp, err
+	return svc, resp, nil
 }
 
 // SetMattermostServiceOptions represents the available SetMattermostService()
 // options.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#createedit-mattermost-notifications-service
+// https://docs.gitlab.com/ee/api/services.html#createedit-mattermost-notifications-service
 type SetMattermostServiceOptions struct {
 	WebHook                   *string `url:"webhook,omitempty" json:"webhook,omitempty"`
 	Username                  *string `url:"username,omitempty" json:"username,omitempty"`
@@ -866,7 +965,7 @@ type SetMattermostServiceOptions struct {
 // SetMattermostService sets Mattermost service for a project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#createedit-mattermost-notifications-service
+// https://docs.gitlab.com/ee/api/services.html#createedit-mattermost-notifications-service
 func (s *ServicesService) SetMattermostService(pid interface{}, opt *SetMattermostServiceOptions, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -885,7 +984,7 @@ func (s *ServicesService) SetMattermostService(pid interface{}, opt *SetMattermo
 // DeleteMattermostService deletes Mattermost service for project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#delete-mattermost-notifications-service
+// https://docs.gitlab.com/ee/api/services.html#delete-mattermost-notifications-service
 func (s *ServicesService) DeleteMattermostService(pid interface{}, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -904,7 +1003,7 @@ func (s *ServicesService) DeleteMattermostService(pid interface{}, options ...Re
 // MicrosoftTeamsService represents Microsoft Teams service settings.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#microsoft-teams
+// https://docs.gitlab.com/ee/api/services.html#microsoft-teams
 type MicrosoftTeamsService struct {
 	Service
 	Properties *MicrosoftTeamsServiceProperties `json:"properties"`
@@ -913,7 +1012,7 @@ type MicrosoftTeamsService struct {
 // MicrosoftTeamsServiceProperties represents Microsoft Teams specific properties.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#microsoft-teams
+// https://docs.gitlab.com/ee/api/services.html#microsoft-teams
 type MicrosoftTeamsServiceProperties struct {
 	WebHook                   string    `json:"webhook"`
 	NotifyOnlyBrokenPipelines BoolValue `json:"notify_only_broken_pipelines"`
@@ -931,7 +1030,7 @@ type MicrosoftTeamsServiceProperties struct {
 // GetMicrosoftTeamsService gets MicrosoftTeams service settings for a project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#get-microsoft-teams-service-settings
+// https://docs.gitlab.com/ee/api/services.html#get-microsoft-teams-service-settings
 func (s *ServicesService) GetMicrosoftTeamsService(pid interface{}, options ...RequestOptionFunc) (*MicrosoftTeamsService, *Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -950,14 +1049,14 @@ func (s *ServicesService) GetMicrosoftTeamsService(pid interface{}, options ...R
 		return nil, resp, err
 	}
 
-	return svc, resp, err
+	return svc, resp, nil
 }
 
 // SetMicrosoftTeamsServiceOptions represents the available SetMicrosoftTeamsService()
 // options.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#create-edit-microsoft-teams-service
+// https://docs.gitlab.com/ee/api/services.html#create-edit-microsoft-teams-service
 type SetMicrosoftTeamsServiceOptions struct {
 	WebHook                   *string `url:"webhook,omitempty" json:"webhook,omitempty"`
 	NotifyOnlyBrokenPipelines *bool   `url:"notify_only_broken_pipelines,omitempty" json:"notify_only_broken_pipelines,omitempty"`
@@ -976,7 +1075,7 @@ type SetMicrosoftTeamsServiceOptions struct {
 // SetMicrosoftTeamsService sets Microsoft Teams service for a project
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#create-edit-microsoft-teams-service
+// https://docs.gitlab.com/ee/api/services.html#create-edit-microsoft-teams-service
 func (s *ServicesService) SetMicrosoftTeamsService(pid interface{}, opt *SetMicrosoftTeamsServiceOptions, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -994,7 +1093,7 @@ func (s *ServicesService) SetMicrosoftTeamsService(pid interface{}, opt *SetMicr
 // DeleteMicrosoftTeamsService deletes Microsoft Teams service for project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#delete-microsoft-teams-service
+// https://docs.gitlab.com/ee/api/services.html#delete-microsoft-teams-service
 func (s *ServicesService) DeleteMicrosoftTeamsService(pid interface{}, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -1052,7 +1151,7 @@ func (s *ServicesService) GetPipelinesEmailService(pid interface{}, options ...R
 		return nil, resp, err
 	}
 
-	return svc, resp, err
+	return svc, resp, nil
 }
 
 // SetPipelinesEmailServiceOptions represents the available
@@ -1148,7 +1247,7 @@ func (s *ServicesService) GetPrometheusService(pid interface{}, options ...Reque
 		return nil, resp, err
 	}
 
-	return svc, resp, err
+	return svc, resp, nil
 }
 
 // SetPrometheusServiceOptions represents the available SetPrometheusService()
@@ -1203,7 +1302,7 @@ func (s *ServicesService) DeletePrometheusService(pid interface{}, options ...Re
 // SlackService represents Slack service settings.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#slack
+// https://docs.gitlab.com/ee/api/services.html#slack
 type SlackService struct {
 	Service
 	Properties *SlackServiceProperties `json:"properties"`
@@ -1212,7 +1311,7 @@ type SlackService struct {
 // SlackServiceProperties represents Slack specific properties.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#slack
+// https://docs.gitlab.com/ee/api/services.html#slack
 type SlackServiceProperties struct {
 	WebHook                   string    `json:"webhook"`
 	Username                  string    `json:"username"`
@@ -1235,7 +1334,7 @@ type SlackServiceProperties struct {
 // GetSlackService gets Slack service settings for a project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#get-slack-service-settings
+// https://docs.gitlab.com/ee/api/services.html#get-slack-service-settings
 func (s *ServicesService) GetSlackService(pid interface{}, options ...RequestOptionFunc) (*SlackService, *Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -1254,14 +1353,14 @@ func (s *ServicesService) GetSlackService(pid interface{}, options ...RequestOpt
 		return nil, resp, err
 	}
 
-	return svc, resp, err
+	return svc, resp, nil
 }
 
 // SetSlackServiceOptions represents the available SetSlackService()
 // options.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#edit-slack-service
+// https://docs.gitlab.com/ee/api/services.html#edit-slack-service
 type SetSlackServiceOptions struct {
 	WebHook                   *string `url:"webhook,omitempty" json:"webhook,omitempty"`
 	Username                  *string `url:"username,omitempty" json:"username,omitempty"`
@@ -1274,7 +1373,7 @@ type SetSlackServiceOptions struct {
 	// TODO: Currently, GitLab ignores this option (not implemented yet?), so
 	// there is no way to set it. Uncomment when this is fixed.
 	// See: https://gitlab.com/gitlab-org/gitlab-ce/issues/49730
-	//ConfidentialNoteChannel   *string `json:"confidential_note_channel,omitempty"`
+	// ConfidentialNoteChannel   *string `json:"confidential_note_channel,omitempty"`
 	ConfidentialNoteEvents *bool   `url:"confidential_note_events,omitempty" json:"confidential_note_events,omitempty"`
 	DeploymentChannel      *string `url:"deployment_channel,omitempty" json:"deployment_channel,omitempty"`
 	DeploymentEvents       *bool   `url:"deployment_events,omitempty" json:"deployment_events,omitempty"`
@@ -1297,7 +1396,7 @@ type SetSlackServiceOptions struct {
 // SetSlackService sets Slack service for a project
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#edit-slack-service
+// https://docs.gitlab.com/ee/api/services.html#edit-slack-service
 func (s *ServicesService) SetSlackService(pid interface{}, opt *SetSlackServiceOptions, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -1316,7 +1415,7 @@ func (s *ServicesService) SetSlackService(pid interface{}, opt *SetSlackServiceO
 // DeleteSlackService deletes Slack service for project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#delete-slack-service
+// https://docs.gitlab.com/ee/api/services.html#delete-slack-service
 func (s *ServicesService) DeleteSlackService(pid interface{}, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -1371,7 +1470,7 @@ func (s *ServicesService) GetSlackSlashCommandsService(pid interface{}, options
 		return nil, resp, err
 	}
 
-	return svc, resp, err
+	return svc, resp, nil
 }
 
 // SetSlackSlashCommandsServiceOptions represents the available SetSlackSlashCommandsService()
@@ -1461,7 +1560,7 @@ func (s *ServicesService) GetMattermostSlashCommandsService(pid interface{}, opt
 		return nil, resp, err
 	}
 
-	return svc, resp, err
+	return svc, resp, nil
 }
 
 // SetMattermostSlashCommandsServiceOptions represents the available SetSlackSlashCommandsService()
@@ -1515,7 +1614,7 @@ func (s *ServicesService) DeleteMattermostSlashCommandsService(pid interface{},
 // YouTrackService represents YouTrack service settings.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#youtrack
+// https://docs.gitlab.com/ee/api/services.html#youtrack
 type YouTrackService struct {
 	Service
 	Properties *YouTrackServiceProperties `json:"properties"`
@@ -1524,7 +1623,7 @@ type YouTrackService struct {
 // YouTrackServiceProperties represents YouTrack specific properties.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#youtrack
+// https://docs.gitlab.com/ee/api/services.html#youtrack
 type YouTrackServiceProperties struct {
 	IssuesURL   string `json:"issues_url"`
 	ProjectURL  string `json:"project_url"`
@@ -1535,7 +1634,7 @@ type YouTrackServiceProperties struct {
 // GetYouTrackService gets YouTrack service settings for a project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#get-youtrack-service-settings
+// https://docs.gitlab.com/ee/api/services.html#get-youtrack-service-settings
 func (s *ServicesService) GetYouTrackService(pid interface{}, options ...RequestOptionFunc) (*YouTrackService, *Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -1554,14 +1653,14 @@ func (s *ServicesService) GetYouTrackService(pid interface{}, options ...Request
 		return nil, resp, err
 	}
 
-	return svc, resp, err
+	return svc, resp, nil
 }
 
 // SetYouTrackServiceOptions represents the available SetYouTrackService()
 // options.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#createedit-youtrack-service
+// https://docs.gitlab.com/ee/api/services.html#createedit-youtrack-service
 type SetYouTrackServiceOptions struct {
 	IssuesURL   *string `url:"issues_url,omitempty" json:"issues_url,omitempty"`
 	ProjectURL  *string `url:"project_url,omitempty" json:"project_url,omitempty"`
@@ -1572,7 +1671,7 @@ type SetYouTrackServiceOptions struct {
 // SetYouTrackService sets YouTrack service for a project
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#createedit-youtrack-service
+// https://docs.gitlab.com/ee/api/services.html#createedit-youtrack-service
 func (s *ServicesService) SetYouTrackService(pid interface{}, opt *SetYouTrackServiceOptions, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
@@ -1591,7 +1690,7 @@ func (s *ServicesService) SetYouTrackService(pid interface{}, opt *SetYouTrackSe
 // DeleteYouTrackService deletes YouTrack service settings for a project.
 //
 // GitLab API docs:
-// https://docs.gitlab.com/ce/api/services.html#delete-youtrack-service
+// https://docs.gitlab.com/ee/api/services.html#delete-youtrack-service
 func (s *ServicesService) DeleteYouTrackService(pid interface{}, options ...RequestOptionFunc) (*Response, error) {
 	project, err := parseID(pid)
 	if err != nil {
